/*		 ITI-FG  Kernel module free public release
 *
 *		     Copyright (C) 1996-2000 GOM mbH.
 *	         Rebenring 33, 38106 Braunschweig, GERMANY
 *		            All rights reserved
 *
 * $Id: swtrig_itifg.c,v 7.0 2000/10/25 09:07:58 cvs Exp $
 *
 */

/* Feature test switches */

/* System headers */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <fcntl.h>
#include <errno.h>
#include <signal.h>
#include <time.h>
#include <termios.h>

#include <sys/ioctl.h>
#include <sys/param.h>

#ifndef __NetBSD__
#include <getopt.h>
#endif

#ifdef linux
#  include <linux/limits.h>	/* PATH_MAX */
#endif

/* Local headers */

#include "itifgExt.h"

/* Macros */

/* File scope variables */

static int device_desc = -1;

/* External variables */

extern char *optarg;
extern int optind, opterr, optopt;

/* External functions */

/* Structures and unions */

/* Signal catching functions */

/* Functions */

/* Main */

int
main (int argc, char *argv[])
{
  int option, board = 0, quit;

  int wait_key = FALSE;

  char device_name[PATH_MAX];

  while (TRUE)
    {
      if ((option = getopt (argc, argv, "b:k?")) == -1) break;
      switch (option)
	{
	case 'b':
	  if (!optarg)
	    printf ("No board selected, using default (%d).\n", board);
	  else
	    {
	      board = atoi (optarg);
	      if (board < 0 || board >= ITI_BOARDS_MAX)
		{
		  printf ("Wrong board selected (%d).\n", board);
		  exit (EXIT_FAILURE);
		}
	    }
	  break;
	case 'k':
	  wait_key = TRUE;
	  break;
	case '?':
	default:
	  printf ("swtrig_itifg: -b board (0) [0-%d]\n", ITI_BOARDS_MAX - 1);
	  printf ("              -k wait for keypress (don't wait)\n");
	  exit (EXIT_FAILURE);
	}
    }
  
  snprintf (device_name, PATH_MAX, "%s%d%s", ITI_NAME_PREFIX, board,
	    ITI_NAME_DATA_POSTFIX);

  if ((device_desc = open (device_name, O_RDWR)) < 0)
    {
      perror ("open");
      exit (EXIT_FAILURE);
    }
  
  if (wait_key)
    {
      while (TRUE)
	{
	  fprintf (stderr, "Press any key to trigger board ('q' for quit).\n");
	  while ((quit = getchar()) == 0);
	  if (quit == 'q') break;
	  if (ioctl (device_desc, GIOC_CR_SET_TRIG, NULL) < 0)
	    {
	      perror ("GIOC_CR_SET_SOFTTRIG");
	      exit (EXIT_FAILURE);
	    }
	}
    }
  else
    {
      if (ioctl (device_desc, GIOC_CR_SET_TRIG, NULL) < 0)
	{
	  perror ("GIOC_CR_SET_SOFTTRIG");
	  exit (EXIT_FAILURE);
	}
    }

  if (close (device_desc) < 0)
    {
      perror ("close");
      exit (EXIT_FAILURE);
    }
  
  exit (EXIT_SUCCESS);
}

